@@ -412,7 +412,8 @@ class Biosemi64Layout(ChannelLayout):
         )
 
         # return make_standard_montage("biosemi64")
-        return make_dig_montage(ch_pos=ch_pos)
+        # return make_dig_montage(ch_pos=ch_pos)
+        return montage
 
 
 # EXT_CHANNEL_NAMES = ['EXT1', 'EXT2', 'EXT3', 'EXT4']
